package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1Object;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.jce.interfaces.PKCS12BagAttributeCarrier;
import java.math.BigInteger;
import java.security.InvalidKeyException;
import java.security.PrivateKey;
import java.util.Arrays;
import java.util.Enumeration;

public class JCESM2PrivateKey implements PrivateKey, PKCS12BagAttributeCarrier {
   private static final long serialVersionUID = 9223372036731319018L;
   private static final byte[] HEADER = new byte[]{48, 65, 2, 1, 0, 48, 19, 6, 7, 42, -122, 72, -50, 61, 2, 1, 6, 8, 42, -127, 28, -49, 85, 1, -126, 45, 4, 39, 48, 37, 2, 1, 1, 4, 32};
   private int bits = 256;
   private byte[] D;
   private PKCS12BagAttributeCarrierImpl attrCarrier = new PKCS12BagAttributeCarrierImpl();

   public JCESM2PrivateKey() {
      this.D = new byte[32];
   }

   public JCESM2PrivateKey(byte[] prik) {
      byte[] var2;
      this.D = var2 = new byte[32];
      if (prik.length >= 32) {
         if (prik.length <= 35) {
            System.arraycopy(prik, prik.length - 32, var2, 0, 32);
         } else {
            this.D = this.parseKey(prik);
         }

      } else {
         throw new InvalidKeyException("Illegal key length:" + prik.length);
      }
   }

   private byte[] parseKey(byte[] prik) {
      try {
         return ((DEROctetString)((ASN1Sequence)ASN1Object.fromByteArray(((DEROctetString)((ASN1Sequence)ASN1Object.fromByteArray(prik)).getObjectAt(2)).getOctets())).getObjectAt(1)).getOctets();
      } catch (Exception var2) {
         throw new InvalidKeyException(var2);
      }
   }

   public int getBits() {
      return this.bits;
   }

   public void setBits(int bits) {
      this.bits = bits;
   }

   public byte[] getD() {
      return this.D;
   }

   public void setD(byte[] d) {
      System.arraycopy(d, 0, this.D, 0, 32);
   }

   public String getAlgorithm() {
      return "SM2";
   }

   public byte[] getEncoded() {
      byte[] var1;
      byte[] var2;
      byte[] var10000 = var2 = new byte[this.D.length + (var1 = HEADER).length];
      JCESM2PrivateKey var10001 = this;
      int var3 = var1.length;
      System.arraycopy(var1, 0, var2, 0, var3);
      byte[] var4 = var10001.D;
      var3 = var1.length;
      int var5 = var4.length;
      System.arraycopy(var4, 0, var2, var3, var5);
      return var10000;
   }

   public String getFormat() {
      return "X.509";
   }

   public void setBagAttribute(DERObjectIdentifier oid, DEREncodable attribute) {
      this.attrCarrier.setBagAttribute(oid, attribute);
   }

   public DEREncodable getBagAttribute(DERObjectIdentifier oid) {
      return this.attrCarrier.getBagAttribute(oid);
   }

   public Enumeration getBagAttributeKeys() {
      return this.attrCarrier.getBagAttributeKeys();
   }

   public int hashCode() {
      return this.D != null ? (new BigInteger(this.D)).hashCode() : 42949672;
   }

   public boolean equals(Object o) {
      if (o == null) {
         return false;
      } else if (this == o) {
         return true;
      } else if (!(o instanceof JCESM2PrivateKey)) {
         return false;
      } else {
         JCESM2PrivateKey var10000 = this;
         JCESM2PrivateKey var2 = (JCESM2PrivateKey)o;
         byte[] o1;
         if ((o1 = var10000.D) != null && var2.D == null || o1 == null && var2.D != null) {
            return false;
         } else {
            byte[] var3;
            return o1 == (var3 = var2.D) ? true : Arrays.equals(o1, var3);
         }
      }
   }
}
